==> kdebase-3.1.4.tar.bz2: kdebase-3.1.4/kicker/buttons/desktopbutton.cpp <==
/*****************************************************************

Copyright (c) 1996-2001 the kicker authors. See file AUTHORS.

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN
AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

******************************************************************/

#include <qtooltip.h>
#include <qdragobject.h>

#include <klocale.h>
#include <kglobalsettings.h>
#include <konq_operations.h>
#include <kfileitem.h>

#include "showdesktop.h"
#include "kicker.h"

#include "desktopbutton.h"
#include "desktopbutton.moc"

DesktopButton::DesktopButton( QWidget* parent )
  : PanelButton( parent, "DesktopButton" )
{
    setToggleButton( TRUE );

    QToolTip::add(this, i18n("Show Desktop"));
    setTitle(i18n("Show Desktop"));
    setIcon("desktop");

    connect( this, SIGNAL(toggled(bool)), ShowDesktop::the(), SLOT(showDesktop(bool)) );
    connect( ShowDesktop::the(), SIGNAL(desktopShown(bool)), this, SLOT(toggle(bool)) );

    setOn( ShowDesktop::the()->desktopShowing() );
}

void DesktopButton::toggle( bool b )
{
    setOn( b );
}

void DesktopButton::dragEnterEvent( QDragEnterEvent *ev )
{
    if ((ev->source() != this) && QUriDrag::canDecode(ev))
        ev->accept(rect());
    else
        ev->ignore(rect());
    PanelButton::dragEnterEvent(ev);
}

void DesktopButton::dropEvent( QDropEvent *ev )
{
    KURL dPath = KGlobalSettings::desktopPath();
    KFileItem item( dPath, QString::fromLatin1( "inode/directory" ), -1 );
    KonqOperations::doDrop( &item, dPath, ev, this );
    PanelButton::dropEvent(ev);
}

==> kdebase-3.2.3.tar.bz2: kdebase-3.2.3/kicker/buttons/desktopbutton.cpp <==
/*****************************************************************

Copyright (c) 1996-2001 the kicker authors. See file AUTHORS.

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN
AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

******************************************************************/

#include <qtooltip.h>
#include <qdragobject.h>

#include <klocale.h>
#include <kglobalsettings.h>
#include <konq_operations.h>
#include <kfileitem.h>

#include "showdesktop.h"
#include "kicker.h"

#include "desktopbutton.h"
#include "desktopbutton.moc"

DesktopButton::DesktopButton( QWidget* parent )
  : PanelButton( parent, "DesktopButton" )
{
    setToggleButton( TRUE );

    QToolTip::add(this, i18n("Show desktop"));
    setTitle(i18n("Desktop Access"));
    setIcon("desktop");

    connect( this, SIGNAL(toggled(bool)), ShowDesktop::the(), SLOT(showDesktop(bool)) );
    connect( ShowDesktop::the(), SIGNAL(desktopShown(bool)), this, SLOT(toggle(bool)) );

    setOn( ShowDesktop::the()->desktopShowing() );
}

void DesktopButton::toggle( bool b )
{
    setOn( b );
}

void DesktopButton::dragEnterEvent( QDragEnterEvent *ev )
{
    if ((ev->source() != this) && KURLDrag::canDecode(ev))
        ev->accept(rect());
    else
        ev->ignore(rect());
    PanelButton::dragEnterEvent(ev);
}

void DesktopButton::dropEvent( QDropEvent *ev )
{
    KURL dPath = KGlobalSettings::desktopPath();
    KFileItem item( dPath, QString::fromLatin1( "inode/directory" ), KFileItem::Unknown );
    KonqOperations::doDrop( &item, dPath, ev, this );
    PanelButton::dropEvent(ev);
}
